@@ -2,7 +2,6 @@ import sys
 import os.path
 from pathlib import Path
 from datetime import datetime
-
 from tkinter import PhotoImage
 from ttkbootstrap.toast import ToastNotification
 import ttkbootstrap as ttk
@@ -15,6 +14,12 @@ from PIL import Image, ImageTk
 import webbrowser
 from random import choice
 
+if __package__:
+    from .toastx import ToastNotificationX
+else:
+    sys.path.append(os.path.dirname(__file__))
+    from toastx import ToastNotificationX
+
 if __package__:
     from .files_earch_frame import FileSearchFrame
     from .device_info import DeviceInfoFrame
@@ -43,6 +48,16 @@ class MainApp(ttk.Frame):
     def __init__(self, master):
 
         super().__init__(master)
+
+        '''
+        toast = ToastNotificationX(
+            image=PATH / 'splash.png',            
+            duration=10000,
+            fullscreen=True,
+        )
+        toast.show_toast()
+        '''
+
         self.pack(fill=BOTH, expand=YES)
         self.hdr_var = ttk.StringVar()
         
@@ -309,9 +324,14 @@ def key_handler(event):
 if __name__ == '__main__':
 
     app = ttk.Window("oCam", "yeti")
+
     app.geometry(DEFAULT_WINSIZE)
     app.attributes('-fullscreen', ENABLE_FULLSCREEN)
-    app.state('zoomed')
+
+    if ENABLE_FULLSCREEN and sys.platform == 'win32':
+        # zoomed is only valid on windows and OSX. It's not supported on X11-based systems.
+        app.state('zoomed')
+
     mp = MainApp(app)
     
     # use either q or esc to close window
