@@ -694,16 +694,22 @@ servo channels:
                 lcd2.noBacklight()
 
                 cols = 16
-                l1 = 'pip install pi4'.ljust(cols)
+                l1 = 'http://'.center(cols)
                 l2 = 'zhangys.org.cn'.rjust(cols)
-                for i in range(cols):
 
-                    l1 = l1[-1] + l1[:-1]
-                    l2 = l2[-1] + l2[:-1]
+                lcd2.printline(0, l1)
+                lcd2.printline(1, l2)
+
+                return
+
+                for i in range(cols):
 
                     lcd2.printline(0, l1)
                     lcd2.printline(1, l2)
                     time.sleep(1)
+
+                    l1 = l1[-1] + l1[:-1]
+                    l2 = l2[-1] + l2[:-1]
                 
                 time.sleep(1)
                 lcd2.noBacklight()
@@ -794,7 +800,7 @@ servo channels:
         # reschedule to run again in 1 second
         self.after(delay, self.UpdateImage, INTERVAL) # frame rate
 
-    def measure_distance(self, flags = [1,0,0,1]):
+    def measure_distance(self, flags = [1,0,0,0]):
         '''
         Measure distances to avoid collision. 
         We cannot put this funciton in a side thread loop. Must use it in the main thread.
@@ -802,24 +808,29 @@ servo channels:
         flags : 4-bit flags for front, back, left and right detection
         '''       
         
+        s = "Distances = "
         if flags[0]:
             self.distance_F = round(acc.front_detection())
+            s = s + 'F' + str(self.distance_F) + ' '
+            if self.distance_F < acc.SAFE_DISTANCE:
+                acc.stop(0.2)
+                acc.move_backward(t_time = 0.2)
+                acc.stop(0.2)
         if flags[1]:
             self.distance_B = round(acc.back_detection())
+            s = s + 'B' + str(self.distance_B) + ' '
+            if self.distance_B < acc.SAFE_DISTANCE:
+                acc.stop(0.2)
+                acc.move_forward(t_time = 0.2)
+                acc.stop(0.2)
         if flags[2]:
             self.distance_L = round(acc.left_detection())
+            s = s + 'L' + str(self.distance_L) + ' '
         if flags[3]:
-            self.distance_R = round(acc.right_detection())        
+            self.distance_R = round(acc.right_detection())
+            s = s + 'R' + str(self.distance_R)
         
-        if self.distance_F < acc.SAFE_DISTANCE:
-            acc.stop(0.2)
-            acc.move_backward(t_time = 0.2)
-            acc.stop(0.2)   
-
-        if self.distance_B < acc.SAFE_DISTANCE:
-            acc.stop(0.2)
-            acc.move_forward(t_time = 0.2)
-            acc.stop(0.2)
+        return s
 
     def get_image(self):
 
@@ -828,8 +839,7 @@ servo channels:
 
         if acc.RUNNING == False:
 
-            self.measure_distance(flags=[1,1,0,0]) # update distances
-            s = "Distances[FBLR] = " + str(self.distance_F) + str(self.distance_B) + ', ' + str(self.distance_L) + ',' + str(self.distance_R)
+            s = self.measure_distance(flags=[1,0,0,0]) # update distances
             draw = ImageDraw.Draw(img)
             ft = ImageFont.truetype('FreeMono.ttf', 25)
             draw.text((10, 10), 
