@@ -65,4 +65,17 @@ class SMBus:
         pass
 
     def read_byte_data(self, address, reg):
-        return 0x00
\ No newline at end of file
+        return 0x00
+
+class pylirc:
+    
+    def init(a = "pylirc", b = "./conf", c = None):
+        pass
+
+    def nextcode(i):
+        pass
+
+    def exit():
+        pass
+
+    
\ No newline at end of file
